Module data

Extractors and response types for some data formats.

Modules

cookiescookies
HTTP cookies.
formform
A form data type.
jsonjson
A Json type to extract and send data as JSON.
multipart_formmultipart-form
Multipart form data types.

Structs

Binary
An extractor type for octet-stream and application/octet-stream data.
FullBody
An extractor that consumes and collects the request body and converts it into a Bytes, ignoring its content type.
Text
An extractor type for text/plain and text/plain; charset=utf-8 data.

Enums

BinaryExtractorError
An error type that’s returned on binary data extraction failure.
FullBodyExtractorError
An error type that’s returned on failure when extracting full data.
TextExtractorError
An error type that’s returned on text data extraction failure.