#[non_exhaustive]pub enum JsonError {
MissingContentType,
InvalidContentType(ToStrError),
UnsupportedMediaType,
ContentTooLarge,
BufferingFailure,
InvalidSyntax {
line: usize,
column: usize,
},
InvalidData {
line: usize,
column: usize,
},
}Available on crate feature
json only.Expand description
An error type that’s returned on failure when extracting or serializing the Json.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingContentType
Returned when the request doesn’t have a Content-Type header.
InvalidContentType(ToStrError)
Returned when the Content-Type value can’t be converted to a string.
UnsupportedMediaType
Returned when the Content-Type has an unsupported media type.
ContentTooLarge
Returned when the content size exceeds the size limit.
BufferingFailure
Returned on failure when collecting the request body frames.
InvalidSyntax
Returned on syntax error when deserializing the body as JSON data.
InvalidData
Returned on semantically incorrect data when deserializing the body as JSON.