Struct WebSocketUpgrade

pub struct WebSocketUpgrade { /* private fields */ }
Available on crate feature websockets only.
An extractor to establish a WebSocket connection.

Implementations

Source

impl WebSocketUpgrade

pub fn select_protocol<Func>( &mut self, selector: Func, ) -> Result<Option<Cow<'_, str>>, WebSocketUpgradeError>
where Func: Fn(&str) -> bool,

Calls the given function for each listed protocol in the Sec-WebSocket-Protocol header and selects the one the given function returned true for.

pub fn set_message_size_limit(&mut self, size_limit: usize) -> &mut Self

Sets the maximum size limit for the message.

pub fn turn_off_auto_unmasking(&mut self) -> &mut Self

Turns off the auto unmasking the messages.

pub fn turn_off_auto_sending_pong(&mut self) -> &mut Self

Turns off automatically sending the pong messages.

pub fn turn_on_auto_closing(&mut self) -> &mut Self

Turns on auto-responding to close messages.

pub fn upgrade<Func, Fut>(self, handle_upgrade_result: Func) -> Response
where Func: FnOnce(Result<WebSocket, WebSocketUpgradeError>) -> Fut + Send + 'static, Fut: Future<Output = ()>,

Returns a Response that should be sent to the client and calls the given callback on upgrade to handle the result.